# Event Outbox

The project is not production ready yet

## Installation

With [pip](https://pypi.org/project/pip/):

```bash
pip install event-outbox
```

With [poetry](https://python-poetry.org/):

```bash
poetry add event-outbox
```
